==> mktcenter-service-1.0.0-vg-20210220.051648-13-sources.jar: com/bizvane/mktcenterservice/models/vo/ActivityManualVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.mktcenterservice.models.po.MktActivityManualPO;

import java.util.Date;

public class ActivityManualVO extends MktActivityManualPO {

    private Long mktCouponId;

    private MemberInfoModel memberInfoModel;

    private String activityCode;

    private Integer activityType;

    private String couponCode;

    private Long couponDefinitionId;

    private Long countTodaySum;//今天领取的总数量

    private Long countAllSum;//领取的总数量

    private String taobaoName;//淘宝昵称

    private String tmallShopPassword;//淘口令

    public Long getCountTodaySum() {
        return countTodaySum;
    }

    public void setCountTodaySum(Long countTodaySum) {
        this.countTodaySum = countTodaySum;
    }

    public Long getCountAllSum() {
        return countAllSum;
    }

    public void setCountAllSum(Long countAllSum) {
        this.countAllSum = countAllSum;
    }

    public MemberInfoModel getMemberInfoModel() {
        return memberInfoModel;
    }

    public void setMemberInfoModel(MemberInfoModel memberInfoModel) {
        this.memberInfoModel = memberInfoModel;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {

        this.couponCode = couponCode;
    }

    public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public Long getMktCouponId() {
        return mktCouponId;
    }

    public void setMktCouponId(Long mktCouponId) {
        this.mktCouponId = mktCouponId;
    }

    public String getTaobaoName() {
        return taobaoName;
    }

    public void setTaobaoName(String taobaoName) {
        this.taobaoName = taobaoName;
    }

    public String getTmallShopPassword() {
        return tmallShopPassword;
    }

    public void setTmallShopPassword(String tmallShopPassword) {
        this.tmallShopPassword = tmallShopPassword;
    }

}

==> mktcenter-service-1.0.3-vg-20220616.105844-4-sources.jar: com/bizvane/mktcenterservice/models/vo/ActivityManualVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.mktcenterservice.models.po.MktActivityManualPO;

import java.util.Date;

public class ActivityManualVO extends MktActivityManualPO {

    private Long mktCouponId;

    private MemberInfoModel memberInfoModel;

    private String activityCode;

    private Integer activityType;

    private String couponCode;

    private Long couponDefinitionId;

    private Long countTodaySum;//今天领取的总数量

    private Long countAllSum;//领取的总数量

    private String taobaoName;//淘宝昵称

    private String tmallShopPassword;//淘口令

    // 活动品牌code
    private String brandCode;

    // 活动状态
    private Integer activityStatus;

    public Long getCountTodaySum() {
        return countTodaySum;
    }

    public void setCountTodaySum(Long countTodaySum) {
        this.countTodaySum = countTodaySum;
    }

    public Long getCountAllSum() {
        return countAllSum;
    }

    public void setCountAllSum(Long countAllSum) {
        this.countAllSum = countAllSum;
    }

    public MemberInfoModel getMemberInfoModel() {
        return memberInfoModel;
    }

    public void setMemberInfoModel(MemberInfoModel memberInfoModel) {
        this.memberInfoModel = memberInfoModel;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {

        this.couponCode = couponCode;
    }

    public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public Long getMktCouponId() {
        return mktCouponId;
    }

    public void setMktCouponId(Long mktCouponId) {
        this.mktCouponId = mktCouponId;
    }

    public String getTaobaoName() {
        return taobaoName;
    }

    public void setTaobaoName(String taobaoName) {
        this.taobaoName = taobaoName;
    }

    public String getTmallShopPassword() {
        return tmallShopPassword;
    }

    public void setTmallShopPassword(String tmallShopPassword) {
        this.tmallShopPassword = tmallShopPassword;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public Integer getActivityStatus() {
        return activityStatus;
    }

    public void setActivityStatus(Integer activityStatus) {
        this.activityStatus = activityStatus;
    }
}
